@@ -2,7 +2,7 @@
 from alibabacloud_computenestsupplier20210521.client import Client as ComputeNestSupplier20210521Client
 from computenestcli.client.base import BaseClient
 
-AP_SOUTHEST_1 = 'ap-southeast-1'
+AP_SOUTHEAST_1 = 'ap-southeast-1'
 
 
 class ComputeNestClient(BaseClient):
@@ -10,10 +10,11 @@ class ComputeNestClient(BaseClient):
     def __init__(self, context):
         super().__init__(context.region_id,
                          context.credentials.access_key_id,
-                         context.credentials.access_key_secret)
+                         context.credentials.access_key_secret,
+                         context.credentials.security_token)
 
     def create_client_compute_nest(self):
-        if self.region_id == AP_SOUTHEST_1:
+        if self.region_id == AP_SOUTHEAST_1:
             self.config.endpoint = f'computenestsupplier.ap-southeast-1.aliyuncs.com'
         else:
             self.config.endpoint = f'computenestsupplier.cn-hangzhou.aliyuncs.com'
