@@ -28,7 +28,7 @@ REGION_ID = 'regionId'
 COMMAND_CONTENT = 'CommandContent'
 ENTITY_ALREADY_EXIST_DRAFT_ARTIFACT = 'EntityAlreadyExist.DraftArtifact'
 ARTIFACT_VERSION_NOT_FOUND = 'EntityNotExist.ArtifactVersion'
-ARTIFACT_STATUS_NOT_SUPPORT_OPERATION = 'NotSupportOperation'
+ARTIFACT_STATUS_NOT_SUPPORT_OPERATION = 'OperationDenied'
 
 
 class ArtifactProcessor:
@@ -223,7 +223,7 @@ class ArtifactProcessor:
                     print("Completion time: ", current_time)
                     print("===========================")
                     self._release_artifact(artifact_id, artifact_name)
-                elif artifact_data.get(UPDATE_ARTIFACT) == False:
+                elif not artifact_data.get(UPDATE_ARTIFACT):
                     artifact_id = artifact_data_list.body.artifacts[0].artifact_id
                     current_time = Util.get_current_time()
                     print("===========================")
